==> vmp-0.7.3.tar.xz: vmp-0.7.3/framework/src/vmp/io.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 10/05/2024
 */

#include <stdio.h>
#include <stdarg.h>
#include <iostream>

#ifndef VAMPIRIA_VMP_IO_H

#define VAMPIRIA_VMP_IO_H 1

namespace vampiria { namespace vmp {

//! File descriptor
typedef FILE * File;

//! Opens the file whose name is the string pointed to by pathname and associates a stream with it
/*!
    @param pathname file path
    @mode mode see man linux fopen
    @return file stream or except in case of failure
*/
vmp::File fopen_wrap(vmp::str pathname,vmp::str mode);

//! Associates a stream with the existing file descriptor
/*!
    @param fd file descriptor
    @mode mode see man linux fopen
    @return file stream or except in case of failure
*/
vmp::File fdopen_wrap(vmp_int fd,vmp::str mode);

//! Reads the next character from stream 
/*!
    @param file file stream
    @return it as an vmp_uint cast to an vmp_int,or EOF on end or ecept in case of failure
*/
vmp_int fgetc_wrap(vmp::File file);

//! For output streams,fflush() forces a write of all userspace buffered data
/*!
    @param file file stream
    @return void or except in case of failure
*/
void fflush_wrap(vmp::File file);

//! Sets the file position indicator for the stream pointed to by file
/*!
    @param file file stream
    @param offset adding  offset bytes to the position specified by whence
    @param whence "set"(start file),"cur"(current position),"end"(end file)
    @return void or except in case of failure
*/
void fseek_wrap(vmp::File file,vmp_uint offset,vmp::str whence);

//! Obtains the current value of the  file  position indicator for the stream pointed to by file
/*!
    @param file file stream
    @return stream position or except in case of failure
*/
vmp_index ftell_wrap(vmp::File file);

//! Reads nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
/*!
    @param ptr pointer to stored data
    @param size size item
    @param nmenb number item
    @param file file stream
    @return number nmemb reads or except in case of failure
*/
vmp_size fread_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);

//! Writs nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
/*!
    @param ptr pointer to read data
    @param size size item
    @param nmenb number item
    @param file file stream
    @return number nmemb writs or except in case of failure
*/
vmp_size fwrite_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);

//! Close file descriptor
/*!
    @param pfile pointer to file descriptor
*/
void fclose_wrap(vmp::File *pfile);

//! init process                
/*!
    @param id process identified
    @param debug debug mode?(true|false).                
*/
void init(vmp::str id,vmp_bool debug=false);

//! Check if the process is debugging mode
/*!
    @return true is debugging mode,otherwise false
*/
vmp_bool is_debug_mode();

//! Returns the process id
/*!
    @return process id
*/
vmp::str id();

//!Format string value(printf style)
/*!
    @param fmt format string
    @param ... format args
    @return string formatted
*/
vmp::str va_wrap(const vmp_char *fmt,va_list ap);

//!Forced unlock io mutex.Used in forced process interruptions,to avoid that the iomutex remains lock (signal, kill thread etc.)
/*!
    @return 1 if unlocked otherwise 0(Used as input in io_recovery_lock() for recovery)
*/
vmp_bool io_forced_unlock();

//! Recovery io mutex lock after a io_forced_unlock() call
/*!
    @param status value returned from io_forced_unlock() function
*/
void io_recovery_lock(vmp_bool status);

//! It writes stderr msg string if debug is setting
/*!
    @param msg message error
    @sa debug_
*/                
void debug_s(vmp::str msg);

//! It writes stderr fmt string if debug is setting
/*!
    @param fmt format string
    @param ... args list format string
    @sa debug_
*/                
void debug(const vmp_char *fmt,...);

//! It writes info stderr msg string
/*!
    @param msg message error
*/  
void info_s(vmp::str msg);

//! It writes info stderr fmt string
/*!
    @param fmt format string
    @param ... args list format string
*/
void info(const vmp_char *fmt,...);

//! It writes warning stderr msg string
/*!
    @param msg message error
*/  
void warning_s(vmp::str msg);
		
//! It writes warning stderr fmt string
/*!
    @param fmt format string
    @param ... args list format string
*/
void warning(const vmp_char *fmt,...);

//! It writes error stderr msg string
/*!
    @param msg message error
*/  
void error_s(vmp::str msg);

//! It writes error stderr fmt string.Print the end of the string the line-end character
/*!
    @param fmt format string
    @param ... args list format string
*/
void error(const vmp_char *fmt,...);

//! It writes error stderr msg string.
/*!
    @param msg message error
*/
void error_raw_s(vmp::str msg);

//! It writes error stderr fmt string.
/*!
    @param fmt format string
    @param ... args list format string
*/
void error_raw(const vmp_char *fmt,...);		

//! It writes output stdout msg string.Print the end of the string the line-end character
/*!
    @param msg message output
*/
void output_s(vmp::str msg);

//! It writes output stdout fmt string.Print the end of the string the line-end character
/*!
    @param fmt format string
    @param ... args list format string
*/                
void output(const vmp_char *fmt,...);

//! It writes output stdout msg string.
/*!
    @param msg message output
*/                
void output_raw_s(vmp::str msg);

//! It writes output stdout fmt string.
/*!
    @param fmt format string
    @param ... args list format string
*/                
void output_raw(const vmp_char *fmt,...);

//! It writes file msg string.
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param msg writes string
    @return exception in case of error
*/  
void output_file_s(vmp::str filename,vmp_bool newfile,vmp::str msg);

//! It writes file fmt string.
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param fmt format string
    @param ... args list format string
    @return exception in case of error
*/  
void output_file(vmp::str filename,vmp_bool newfile,const vmp_char *fmt,...);

//! Writes the input vector strings to the file by adding newline between the strings
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param lines lines string
    @return exception in case of error
*/
void output_file_lines(vmp::str filename,vmp_bool newfile,vmp::vector<vmp::str> lines);

//! Reads a line on stdin                
/*!
    @param input result of reading
    @return the string read or the string empty if it does not read.if input read is == '\n' return \n values.                
*/                               
vmp::str input();

//! Reads from a text file and inserts the lines into a vector
/*!
    @param filename file name
    @return A vector of the lines of the file
*/
vmp::vector<vmp::str> input_file(vmp::str filename);

//! Reads from a text file and inserts the lines into a string
/*!
    @param filename file name
    @return A string of the file
*/
vmp::str input_file_s(vmp::str filename);

//! Terminates a process and exits with success value
void exit_ok();

//! Terminates a process and exits with failure value
/*!
    @param msg message error
*/
void exit_failure_s(vmp::str msg);

//! Terminates a process and exits with failure value
/*!
    @param fmt format string
    @param ... args list format string
*/
void exit_failure(const vmp_char *fmt,...);

//! Opens a write stream file associated with the filedescriptor
/*!
    @param fd fd input
    @return file stream or except in case of failure
*/
vmp::File fd_stream(vmp_int fd);

//! Write data in filestream
/*!
    @param f file stream
    @param data data write(except errno)
*/
void stream_write(vmp::File f,vmp::str data);

//!Close File stream assign (*f)=0
/*!
    @param pointer to pointer stream
*/
void stream_close(FILE **f);

//!Copy a file
/*!
    @param src source file
    @param dst destination file
    @return void or except in case of failure
*/
void copy_file(vmp::str src,vmp::str dst);

//!Move a file
/*!
    @param src source file
    @param dst destination file
    @return void or except in case of failure
*/
void move_file(vmp::str src,vmp::str dst);

}}

#endif

==> vmp-0.8.1.tar.xz: vmp-0.8.1/framework/src/vmp/io.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 26/03/2025
 */

#include <stdio.h>
#include <stdarg.h>
#include <iostream>

#ifndef VAMPIRIA_VMP_IO_H

#define VAMPIRIA_VMP_IO_H 1

namespace vampiria { namespace vmp {

//! File descriptor
typedef FILE * File;

//! Opens the file whose name is the string pointed to by pathname and associates a stream with it
/*!
    @param pathname file path
    @mode mode see man linux fopen
    @return file stream or except in case of failure
*/
vmp::File fopen_wrap(vmp::str pathname,vmp::str mode);

//! Associates a stream with the existing file descriptor
/*!
    @param fd file descriptor
    @mode mode see man linux fopen
    @return file stream or except in case of failure
*/
vmp::File fdopen_wrap(vmp_int fd,vmp::str mode);

//! Reads the next character from stream 
/*!
    @param file file stream
    @return it as an vmp_uint cast to an vmp_int,or EOF on end or ecept in case of failure
*/
vmp_int fgetc_wrap(vmp::File file);

//! For output streams,fflush() forces a write of all userspace buffered data
/*!
    @param file file stream
    @return void or except in case of failure
*/
void fflush_wrap(vmp::File file);

//! Sets the file position indicator for the stream pointed to by file
/*!
    @param file file stream
    @param offset adding  offset bytes to the position specified by whence
    @param whence "set"(start file),"cur"(current position),"end"(end file)
    @return void or except in case of failure
*/
void fseek_wrap(vmp::File file,vmp_int offset,vmp::str whence);

//! Obtains the current value of the  file  position indicator for the stream pointed to by file
/*!
    @param file file stream
    @return stream position or except in case of failure
*/
vmp_index ftell_wrap(vmp::File file);

//! Reads nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
/*!
    @param ptr pointer to stored data
    @param size size item
    @param nmenb number item
    @param file file stream
    @return number nmemb reads or except in case of failure
*/
vmp_size fread_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);

//! Writs nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
/*!
    @param ptr pointer to read data
    @param size size item
    @param nmenb number item
    @param file file stream
    @return number nmemb writs or except in case of failure
*/
vmp_size fwrite_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);

//! Close file descriptor
/*!
    @param pfile pointer to file descriptor
*/
void fclose_wrap(vmp::File *pfile);

//! init process                
/*!
    @param id process identified
    @param debug debug mode?(true|false).                
*/
void init(vmp::str id,vmp_bool debug=false);

//! Check if the process is debugging mode
/*!
    @return true is debugging mode,otherwise false
*/
vmp_bool is_debug_mode();

//! Returns the process id
/*!
    @return process id
*/
vmp::str id();

//!Format string value(printf style)
/*!
    @param fmt format string
    @param ... format args
    @return string formatted
*/
vmp::str va_wrap(const vmp_char *fmt,va_list ap);

//!Forced unlock io mutex.Used in forced process interruptions,to avoid that the iomutex remains lock (signal, kill thread etc.)
/*!
    @return 1 if unlocked otherwise 0(Used as input in io_recovery_lock() for recovery)
*/
vmp_bool io_forced_unlock();

//! Recovery io mutex lock after a io_forced_unlock() call
/*!
    @param status value returned from io_forced_unlock() function
*/
void io_recovery_lock(vmp_bool status);

//! It writes stderr msg string if debug is setting
/*!
    @param msg message error
    @sa debug_
*/                
void debug_s(vmp::str msg);

//! It writes stderr fmt string if debug is setting
/*!
    @param fmt format string
    @param ... args list format string
    @sa debug_
*/                
void debug(const vmp_char *fmt,...);

//! It writes info stderr msg string
/*!
    @param msg message error
*/  
void info_s(vmp::str msg);

//! It writes info stderr fmt string
/*!
    @param fmt format string
    @param ... args list format string
*/
void info(const vmp_char *fmt,...);

//! It writes warning stderr msg string
/*!
    @param msg message error
*/  
void warning_s(vmp::str msg);
		
//! It writes warning stderr fmt string
/*!
    @param fmt format string
    @param ... args list format string
*/
void warning(const vmp_char *fmt,...);

//! It writes error stderr msg string
/*!
    @param msg message error
*/  
void error_s(vmp::str msg);

//! It writes error stderr fmt string.Print the end of the string the line-end character
/*!
    @param fmt format string
    @param ... args list format string
*/
void error(const vmp_char *fmt,...);

//! It writes error stderr msg string.
/*!
    @param msg message error
*/
void error_raw_s(vmp::str msg);

//! It writes error stderr fmt string.
/*!
    @param fmt format string
    @param ... args list format string
*/
void error_raw(const vmp_char *fmt,...);		

//! It writes output stdout msg string.Print the end of the string the line-end character
/*!
    @param msg message output
*/
void output_s(vmp::str msg);

//! It writes output stdout fmt string.Print the end of the string the line-end character
/*!
    @param fmt format string
    @param ... args list format string
*/                
void output(const vmp_char *fmt,...);

//! It writes output stdout msg string.
/*!
    @param msg message output
*/                
void output_raw_s(vmp::str msg);

//! It writes output stdout fmt string.
/*!
    @param fmt format string
    @param ... args list format string
*/                
void output_raw(const vmp_char *fmt,...);

//! It writes file msg string.
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param msg writes string
    @return exception in case of error
*/  
void output_file_s(vmp::str filename,vmp_bool newfile,vmp::str msg);

//! It writes file fmt string.
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param fmt format string
    @param ... args list format string
    @return exception in case of error
*/  
void output_file(vmp::str filename,vmp_bool newfile,const vmp_char *fmt,...);

//! Writes the input vector strings to the file by adding newline between the strings
/*!
    @param filename file name
    @param newfile  true (create new file),false append data
    @param lines lines string
    @return exception in case of error
*/
void output_file_lines(vmp::str filename,vmp_bool newfile,vmp::vector<vmp::str> lines);

//! Reads a line on stdin                
/*!
    @param input result of reading
    @return the string read or the string empty if it does not read.if input read is == '\n' return \n values.                
*/                               
vmp::str input();

//! Reads from a text file and inserts the lines into a vector
/*!
    @param filename file name
    @return A vector of the lines of the file
*/
vmp::vector<vmp::str> input_file(vmp::str filename);

//! Reads from a text file and inserts the lines into a string
/*!
    @param filename file name
    @return a string of the file
*/
vmp::str input_file_s(vmp::str filename);

//!Reads part of a file
/*!
    @param filename file name
    @param init start reading position
    @param size number of bytes read
    @return the string of the file part read
*/
vmp::str input_part_file(vmp::str filename,vmp_int init,vmp_size size);

//! Terminates a process and exits with success value
void exit_ok();

//! Terminates a process and exits with failure value
/*!
    @param msg message error
*/
void exit_failure_s(vmp::str msg);

//! Terminates a process and exits with failure value
/*!
    @param fmt format string
    @param ... args list format string
*/
void exit_failure(const vmp_char *fmt,...);

//! Opens a write stream file associated with the filedescriptor
/*!
    @param fd fd input
    @return file stream or except in case of failure
*/
vmp::File fd_stream(vmp_int fd);

//! Write data in filestream
/*!
    @param f file stream
    @param data data write(except errno)
*/
void stream_write(vmp::File f,vmp::str data);

//!Close File stream assign (*f)=0
/*!
    @param pointer to pointer stream
*/
void stream_close(FILE **f);

//!Copy a file
/*!
    @param src source file
    @param dst destination file
    @return void or except in case of failure
*/
void copy_file(vmp::str src,vmp::str dst);

//!Move a file
/*!
    @param src source file
    @param dst destination file
    @return void or except in case of failure
*/
void move_file(vmp::str src,vmp::str dst);

}}

#endif
